@@ -63,6 +63,8 @@ enum
 
 
 
+#define XFCE_MIXER_PLUGIN_DEFAULT_COMMAND   "xfce4-mixer"
+
 #ifdef HAVE_KEYBINDER
 #define XFCE_MIXER_PLUGIN_RAISE_VOLUME_KEY  "XF86AudioRaiseVolume"
 #define XFCE_MIXER_PLUGIN_LOWER_VOLUME_KEY  "XF86AudioLowerVolume"
@@ -303,7 +305,7 @@ xfce_mixer_plugin_construct (XfcePanelPlugin *plugin)
   xfce_panel_plugin_menu_show_configure (plugin);
 
   /* Add menu item for muting */
-  mixer_plugin->mute_menu_item = gtk_check_menu_item_new_with_mnemonic (_("_Mute"));
+  mixer_plugin->mute_menu_item = gtk_check_menu_item_new_with_mnemonic (_("Mu_te"));
   xfce_panel_plugin_menu_insert_item (plugin, GTK_MENU_ITEM (mixer_plugin->mute_menu_item));
   g_signal_connect_swapped (G_OBJECT (mixer_plugin->mute_menu_item), "toggled", G_CALLBACK (xfce_mixer_plugin_mute_item_toggled), mixer_plugin);
   gtk_widget_show (mixer_plugin->mute_menu_item);
@@ -311,7 +313,7 @@ xfce_mixer_plugin_construct (XfcePanelPlugin *plugin)
   /* Add menu item for running the user-defined command */
   command_image = gtk_image_new_from_icon_name ("multimedia-volume-control", GTK_ICON_SIZE_MENU);
   gtk_widget_show (command_image);
-  command_menu_item = gtk_image_menu_item_new_with_mnemonic (_("_Run Audio Mixer"));
+  command_menu_item = gtk_image_menu_item_new_with_mnemonic (_("Run Audio Mi_xer"));
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (command_menu_item), command_image);
   xfce_panel_plugin_menu_insert_item (plugin, GTK_MENU_ITEM (command_menu_item));
   g_signal_connect_swapped (G_OBJECT (command_menu_item), "activate", G_CALLBACK (xfce_mixer_plugin_command_item_activated), mixer_plugin);
@@ -361,7 +363,9 @@ xfce_mixer_plugin_set_property (GObject      *object,
   gchar              *track_label = NULL;
   GstMixerTrack      *track = NULL;
   XfceMixerTrackType  track_type = G_TYPE_INVALID;
+#ifdef HAVE_KEYBINDER
   gboolean            enable_keyboard_shortcuts;
+#endif
 
   switch(prop_id)
     {
@@ -604,6 +608,7 @@ xfce_mixer_plugin_size_changed (XfcePanelPlugin *plugin,
                                 gint             size)
 {
   XfceMixerPlugin *mixer_plugin = XFCE_MIXER_PLUGIN (plugin);
+  gint             icon_size;
 
   g_return_val_if_fail (mixer_plugin != NULL, FALSE);
 
@@ -611,11 +616,12 @@ xfce_mixer_plugin_size_changed (XfcePanelPlugin *plugin,
   size /= xfce_panel_plugin_get_nrows (XFCE_PANEL_PLUGIN (mixer_plugin));
 
   /* Determine size for the volume button icons */
-  size -= 2 + 2 * MAX (mixer_plugin->button->style->xthickness, mixer_plugin->button->style->ythickness);
+  icon_size = size - 2 - 2 * MAX (mixer_plugin->button->style->xthickness, mixer_plugin->button->style->ythickness);
 
   /* Set volume button icon size and update the volume button */
-  xfce_volume_button_set_icon_size (XFCE_VOLUME_BUTTON (mixer_plugin->button), size);
+  xfce_volume_button_set_icon_size (XFCE_VOLUME_BUTTON (mixer_plugin->button), icon_size);
   xfce_volume_button_update (XFCE_VOLUME_BUTTON (mixer_plugin->button));
+  gtk_widget_set_size_request (mixer_plugin->button, size, size);
 
   return TRUE;
 }
@@ -860,18 +866,32 @@ static void
 xfce_mixer_plugin_button_volume_changed (XfceMixerPlugin  *mixer_plugin,
                                          gdouble           button_volume)
 {
-  gint   volume;
+  gint   old_volume;
+  gint   new_volume;
 
   g_return_if_fail (mixer_plugin != NULL);
   g_return_if_fail (GST_IS_MIXER (mixer_plugin->card));
   g_return_if_fail (GST_IS_MIXER_TRACK (mixer_plugin->track));
 
+  old_volume = xfce_mixer_plugin_get_volume (mixer_plugin);
   /* Convert relative to absolute volume */
-  volume = (gint) round (mixer_plugin->track->min_volume + (button_volume * (mixer_plugin->track->max_volume - mixer_plugin->track->min_volume)));
+  new_volume = (gint) round (mixer_plugin->track->min_volume + (button_volume * (mixer_plugin->track->max_volume - mixer_plugin->track->min_volume)));
 
-  xfce_mixer_debug ("button emitted 'volume-changed', new volume is %d (%d%%)", volume, (gint) round (button_volume * 100));
+  xfce_mixer_debug ("button emitted 'volume-changed', new volume is %d (%d%%)", new_volume, (gint) round (button_volume * 100));
 
-  xfce_mixer_plugin_set_volume (mixer_plugin, volume);
+  xfce_mixer_plugin_set_volume (mixer_plugin, new_volume);
+
+  /* Mute when volume reaches the minimum, unmute if volume is raised from the minimum */
+  if (old_volume > mixer_plugin->track->min_volume && new_volume == mixer_plugin->track->min_volume)
+    {
+      xfce_mixer_plugin_set_muted (mixer_plugin, TRUE);
+      xfce_mixer_plugin_update_muted (mixer_plugin, TRUE);
+    }
+  else if (old_volume == mixer_plugin->track->min_volume && new_volume > mixer_plugin->track->min_volume)
+    {
+      xfce_mixer_plugin_set_muted (mixer_plugin, FALSE);
+      xfce_mixer_plugin_update_muted (mixer_plugin, FALSE);
+    }
 }
 
 
@@ -1072,13 +1092,13 @@ xfce_mixer_plugin_volume_key_pressed (const char *keystring,
   xfce_mixer_plugin_set_volume (mixer_plugin, new_volume);
   xfce_mixer_plugin_update_volume (mixer_plugin, new_volume);
 
-  /* Mute when volume reaches 0%, unmute if volume is raised from 0% */
-  if (old_volume > 0 && new_volume == 0)
+  /* Mute when volume reaches the minimum, unmute if volume is raised from the minimum */
+  if (old_volume > mixer_plugin->track->min_volume && new_volume == mixer_plugin->track->min_volume)
     {
       xfce_mixer_plugin_set_muted (mixer_plugin, TRUE);
       xfce_mixer_plugin_update_muted (mixer_plugin, TRUE);
     }
-  else if (old_volume == 0 && new_volume > 0)
+  else if (old_volume == mixer_plugin->track->min_volume && new_volume > mixer_plugin->track->min_volume)
     {
       xfce_mixer_plugin_set_muted (mixer_plugin, FALSE);
       xfce_mixer_plugin_update_muted (mixer_plugin, FALSE);
